j\_chess\_lib.communication.schema package
==========================================

This package contains classes created using the j-chess-xsd_

.. _j-chess-xsd: https://github.com/JoKrus/j-chess-xsd

Submodules
----------

j\_chess\_lib.communication.schema.j\_chess\_message module
-----------------------------------------------------------

.. automodule:: j_chess_lib.communication.schema.j_chess_message
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: j_chess_lib.communication.schema
   :members:
   :undoc-members:
   :show-inheritance:
